This library will contain all my important composition tools. At this moment there are some tools there for random data generation and permutation, a pdf generator and a fractal tree structure which is the base of one of my most important tools: fractal music. Work in progress! No documenation for now so you have to read the code :-]]

Prerequisites
=============

To run the tests locally, the following external tools are required:

1. **pdftocairo** (from Poppler-utils)
    - **Linux (Ubuntu/Debian)**: `sudo apt install poppler-utils`
    - **macOS**: `brew install poppler`
    - **Windows**: [Download Poppler for Windows](https://github.com/oschwartz10612/poppler-windows) and add it to your PATH.

2. **compare** (from ImageMagick)
    - **Linux (Ubuntu/Debian):** `sudo apt install imagemagick`
    - **macOS:** `brew install imagemagick`
    - **Windows:** [Download ImageMagick](https://imagemagick.org/script/download.php#windows)
